package VMOMI::ClusterHostInfraUpdateHaModeActionOperationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
